@@ -84,9 +84,11 @@ pub fn init(
                 // try to init
                 match init_driver(drv_type, init_params.clone()) {
                     Ok(driver) => {
+                        info!("Driver initialized: {:?}", driver.get_driver_type());
                         return Ok(driver);
                     }
-                    Err(_) => {
+                    Err(e) => {
+                        debug!("{:?} driver initialization failed: {}", drv_type, e);
                         continue;
                     }
                 }
@@ -94,7 +96,16 @@ pub fn init(
             info!("No driver available");
             Err(MicrovmiError::NoDriverAvailable)
         }
-        Some(drv_type) => init_driver(drv_type, init_params),
+        Some(drv_type) => match init_driver(drv_type, init_params) {
+            Ok(driver) => {
+                info!("Driver initialized: {:?}", driver.get_driver_type());
+                Ok(driver)
+            }
+            Err(e) => {
+                debug!("{:?} driver initialization failed: {}", driver_type, e);
+                Err(e)
+            }
+        },
     }
 }
 
@@ -108,9 +119,9 @@ fn init_driver(
         ..Default::default()
     });
     #[allow(clippy::match_single_binding)]
-    let res: Result<Box<dyn Introspectable>, MicrovmiError> = match driver_type {
+    match driver_type {
         #[cfg(feature = "kvm")]
-        DriverType::KVM => Ok(Box::new(Kvm::new(create_kvmi(), _init_params)?)),
+        DriverType::KVM => Ok(Box::new(Kvm::new(create_kvmi()?, _init_params)?)),
         #[cfg(feature = "mflow")]
         DriverType::Memflow => Ok(Box::new(Memflow::new(_init_params)?)),
         #[cfg(feature = "virtualbox")]
@@ -119,14 +130,5 @@ fn init_driver(
         DriverType::Xen => Ok(Box::new(Xen::new(_init_params)?)),
         #[allow(unreachable_patterns)]
         _ => Err(MicrovmiError::DriverNotCompiled(driver_type)),
-    };
-    match res {
-        Ok(ref driver) => {
-            info!("Driver initialized: {:?}", driver.get_driver_type());
-        }
-        Err(ref e) => {
-            debug!("{:?} driver initialization failed: {}", driver_type, e);
-        }
     }
-    res
 }
